-- Payment Register Application
-- October 15, 2014

-- This SQL code must be executed after SaveToDB Framework installation!

CREATE TABLE [Account](
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [Name] [nvarchar](50) NOT NULL,
 CONSTRAINT [PK_Account] PRIMARY KEY ([ID]),
 CONSTRAINT [IX_Account] UNIQUE ([Name])
);
GO

CREATE TABLE [Company](
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [Name] [nvarchar](50) NOT NULL,
 CONSTRAINT [PK_Company] PRIMARY KEY ([ID]),
 CONSTRAINT [IX_Company] UNIQUE ([Name])
);
GO

CREATE TABLE [Item](
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [Name] [nvarchar](50) NOT NULL,
 CONSTRAINT [PK_Item] PRIMARY KEY ([ID]),
 CONSTRAINT [IX_Item] UNIQUE ([Name])
);
GO

CREATE TABLE [Payment](
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [Date] [datetime] NULL,
    [Sum] [money] NULL,
    [AccountID] [int] NULL,
    [CompanyID] [int] NULL,
    [ItemID] [int] NULL,
    [Comment] [nvarchar](50) NULL,
 CONSTRAINT [PK_Payment] PRIMARY KEY ([ID])
);
GO

ALTER TABLE [Payment] ADD CONSTRAINT [FK_Payment_Account] FOREIGN KEY([AccountID])
REFERENCES [Account] ([ID])
ON UPDATE CASCADE;
GO

ALTER TABLE [Payment] ADD CONSTRAINT [FK_Payment_Company] FOREIGN KEY([CompanyID])
REFERENCES [Company] ([ID])
ON UPDATE CASCADE;
GO

ALTER TABLE [Payment] ADD CONSTRAINT [FK_Payment_Item] FOREIGN KEY([ItemID])
REFERENCES [Item] ([ID])
ON UPDATE CASCADE;
GO

SET IDENTITY_INSERT [Account] ON;
GO

INSERT INTO [Account] ([ID],[Name]) VALUES (1,N'My Bank');
GO

SET IDENTITY_INSERT [Account] OFF;
GO

SET IDENTITY_INSERT [Company] ON;
GO

INSERT INTO [Company] ([ID],[Name]) VALUES (1,N'Carnation, Inc');
GO
INSERT INTO [Company] ([ID],[Name]) VALUES (2,N'Cornflower, Corp');
GO
INSERT INTO [Company] ([ID],[Name]) VALUES (3,N'Corporate Tax');
GO
INSERT INTO [Company] ([ID],[Name]) VALUES (4,N'Income Taxes');
GO
INSERT INTO [Company] ([ID],[Name]) VALUES (5,N'Land, Inc');
GO
INSERT INTO [Company] ([ID],[Name]) VALUES (6,N'Rose, Inc');
GO
INSERT INTO [Company] ([ID],[Name]) VALUES (7,N'Salary Taxes');
GO
INSERT INTO [Company] ([ID],[Name]) VALUES (8,N'Water, Inc');
GO

SET IDENTITY_INSERT [Company] OFF;
GO

SET IDENTITY_INSERT [Item] ON;
GO

INSERT INTO [Item] ([ID],[Name]) VALUES (1,N'Expenses');
GO
INSERT INTO [Item] ([ID],[Name]) VALUES (2,N'Payroll');
GO
INSERT INTO [Item] ([ID],[Name]) VALUES (3,N'Revenue');
GO
INSERT INTO [Item] ([ID],[Name]) VALUES (4,N'Taxes');
GO

SET IDENTITY_INSERT [Item] OFF;
GO

SET IDENTITY_INSERT [Payment] ON;
GO

INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (1,N'2013.12.31',10000,1,NULL,NULL,N'Opening balance');
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (2,N'2014.01.10',200000,1,6,3,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (3,N'2014.01.10',-50000,1,5,1,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (4,N'2014.01.31',-13000,1,4,4,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (5,N'2014.01.31',-29580,1,7,4,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (6,N'2014.01.31',-87000,1,NULL,2,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (7,N'2014.02.10',300000,1,6,3,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (8,N'2014.02.10',100000,1,1,3,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (9,N'2014.02.10',-50000,1,8,1,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (10,N'2014.02.10',-100000,1,5,1,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (11,N'2014.02.28',-13000,1,4,4,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (12,N'2014.02.28',-29580,1,7,4,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (13,N'2014.02.28',-87000,1,NULL,2,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (14,N'2014.03.10',300000,1,6,3,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (15,N'2014.03.10',200000,1,1,3,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (16,N'2014.03.10',100000,1,2,3,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (17,N'2014.03.15',-36000,1,3,4,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (18,N'2014.03.31',-26000,1,4,4,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (19,N'2014.03.31',-50000,1,8,1,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (20,N'2014.03.31',-59160,1,7,4,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (21,N'2014.03.31',-100000,1,5,1,NULL);
GO
INSERT INTO [Payment] ([ID],[Date],[Sum],[AccountID],[CompanyID],[ItemID],[Comment]) VALUES (22,N'2014.03.31',-174000,1,NULL,2,NULL);
GO

SET IDENTITY_INSERT [Payment] OFF;
GO

INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES (N'SELECT
    p.ID
    , p.[Date]
    , p.[Sum]
    , a.Name AS AccountName
    , c.Name AS CompanyName
    , i.Name AS ItemName
    , p.Comment
FROM
    Payment p
    LEFT OUTER JOIN Item i ON i.ID = p.ItemID
    LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
    LEFT OUTER JOIN Account a ON a.ID = p.AccountID
WHERE
    COALESCE(a.Name, '') = COALESCE(@AccountName, a.Name, '')
    AND COALESCE(c.Name, '') = COALESCE(@CompanyName, c.Name, '')
    AND COALESCE(i.Name, '') = COALESCE(@ItemName, i.Name, '')
',N'Payments',N'CODE',N'INSERT INTO [Account] ([Name])
SELECT
    t.Name
FROM
    (SELECT @AccountName AS Name) t
    LEFT OUTER JOIN Account a ON a.Name = t.Name
WHERE
    t.Name IS NOT NULL
    AND a.Name IS NULL;
GO

INSERT INTO [Item] ([Name])
SELECT
    t.Name
FROM
    (SELECT @ItemName AS Name) t
    LEFT OUTER JOIN Item a ON a.Name = t.Name
WHERE
    t.Name IS NOT NULL
    AND a.Name IS NULL;
GO

INSERT INTO [Company] ([Name])
SELECT
    t.Name
FROM
    (SELECT @CompanyName AS Name) t
    LEFT OUTER JOIN Company a ON a.Name = t.Name
WHERE
    t.Name IS NOT NULL
    AND a.Name IS NULL;
GO

INSERT INTO Payment
    ([Date]
    ,[Sum]
    ,[AccountID]
    ,[CompanyID]
    ,[ItemID]
    ,[Comment])
SELECT
    @Date AS [Date]
    , @Sum AS [Sum]
    , a.ID AS AccountID
    , c.ID AS CompanyID
    , i.ID AS ItemID
    , @Comment AS Comment
FROM
    (SELECT MIN(ID) AS ID FROM Account WHERE Name = @AccountName) a
    , (SELECT MIN(ID) AS ID FROM Company WHERE Name = @CompanyName) c
    , (SELECT MIN(ID) AS ID FROM Item WHERE Name = @ItemName) i;
GO
',N'INSERT INTO [Account] ([Name])
SELECT
    t.Name
FROM
    (SELECT @AccountName AS Name) t
    LEFT OUTER JOIN Account a ON a.Name = t.Name
WHERE
    t.Name IS NOT NULL
    AND a.Name IS NULL;
GO

INSERT INTO [Item] ([Name])
SELECT
    t.Name
FROM
    (SELECT @ItemName AS Name) t
    LEFT OUTER JOIN Item a ON a.Name = t.Name
WHERE
    t.Name IS NOT NULL
    AND a.Name IS NULL;
GO

INSERT INTO [Company] ([Name])
SELECT
    t.Name
FROM
    (SELECT @CompanyName AS Name) t
    LEFT OUTER JOIN Company a ON a.Name = t.Name
WHERE
    t.Name IS NOT NULL
    AND a.Name IS NULL;
GO

DELETE FROM Payment WHERE ID = @ID;
GO

SET IDENTITY_INSERT Payment ON;
GO

INSERT INTO Payment
    ([ID]
    ,[Date]
    ,[Sum]
    ,[AccountID]
    ,[CompanyID]
    ,[ItemID]
    ,[Comment])
SELECT
    @ID AS ID
    , @Date AS [Date]
    , @Sum AS [Sum]
    , a.ID AS AccountID
    , c.ID AS CompanyID
    , i.ID AS ItemID
    , @Comment AS Comment
FROM
    (SELECT MIN(ID) AS ID FROM Account WHERE Name = @AccountName) a
    , (SELECT MIN(ID) AS ID FROM Company WHERE Name = @CompanyName) c
    , (SELECT MIN(ID) AS ID FROM Item WHERE Name = @ItemName) i;
GO

SET IDENTITY_INSERT Payment OFF;
GO
',N'DELETE FROM Payment WHERE ID = @ID;
GO
');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES (N'SELECT
    p.RowNumber AS N
    , MAX(p.[Level]) AS [Level]
    , p.ItemType
    , p.ItemName
    , p.CompanyName
    , COALESCE(MAX(t.TRANSLATED_NAME), MAX(p.Name)) AS Name
    , SUM(p.Total) AS Total
    , SUM(p.Jan) AS Jan
    , SUM(p.Feb) AS Feb
    , SUM(p.Mar) AS Mar
    , SUM(p.Apr) AS Apr
    , SUM(p.May) AS May
    , SUM(p.Jun) AS Jun
    , SUM(p.Jul) AS Jul
    , SUM(p.Aug) AS Aug
    , SUM(p.Sep) AS Sep
    , SUM(p.Oct) AS Oct
    , SUM(p.Nov) AS Nov
    , SUM(p.[Dec]) AS [Dec]
FROM
    (
    -- Companies
    SELECT
        p.RowNumber
        , 0 AS [Level]
        , p.ItemType
        , p.ItemName
        , p.CompanyName
        , ''  '' + p.CompanyName AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N''Expences'' ELSE N''Income'' END AS NVARCHAR(50)) AS ItemType
            , p.ItemName
            , p.CompanyName
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            (
            SELECT
                p.ID
                , p.[Date]
                , p.[Sum]
                , a.Name AS AccountName
                , c.Name AS CompanyName
                , i.Name AS ItemName
                , p.Comment
            FROM
                Payment p
                LEFT OUTER JOIN Item i ON i.ID = p.ItemID
                LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
                LEFT OUTER JOIN Account a ON a.ID = p.AccountID
            ) p
        WHERE
            p.CompanyName IS NOT NULL
            AND DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType,
        p.ItemName,
        p.CompanyName

    -- Total Items
    UNION ALL
    SELECT
        p.RowNumber
        , 1 AS [Level]
        , p.ItemType
        , p.ItemName
        , NULL AS CompanyName
        , p.ItemName AS [Name]
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N''Expences'' ELSE N''Income'' END AS NVARCHAR(50)) AS ItemType
            , p.ItemName
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            (
            SELECT
                p.ID
                , p.[Date]
                , p.[Sum]
                , a.Name AS AccountName
                , c.Name AS CompanyName
                , i.Name AS ItemName
                , p.Comment
            FROM
                Payment p
                LEFT OUTER JOIN Item i ON i.ID = p.ItemID
                LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
                LEFT OUTER JOIN Account a ON a.ID = p.AccountID
            ) p
        WHERE
            p.ItemName IS NOT NULL
            AND DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType,
        p.ItemName

    -- Total Income/Expenses
    UNION ALL
    SELECT
        p.RowNumber
        , 2 AS [Level]
        , p.ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N''Total '' + p.ItemType AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N''Expences'' ELSE N''Income'' END AS NVARCHAR(50)) AS ItemType
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            (
            SELECT
                p.ID
                , p.[Date]
                , p.[Sum]
                , a.Name AS AccountName
                , c.Name AS CompanyName
                , i.Name AS ItemName
                , p.Comment
            FROM
                Payment p
                LEFT OUTER JOIN Item i ON i.ID = p.ItemID
                LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
                LEFT OUTER JOIN Account a ON a.ID = p.AccountID
            ) p
        WHERE
            DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType

    -- Net Chanhge
    UNION ALL
    SELECT
        3 AS RowNumber
        , 2 AS [Level]
        , N''Net Change'' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N''Net Change'' AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            (
            SELECT
                p.ID
                , p.[Date]
                , p.[Sum]
                , a.Name AS AccountName
                , c.Name AS CompanyName
                , i.Name AS ItemName
                , p.Comment
            FROM
                Payment p
                LEFT OUTER JOIN Item i ON i.ID = p.ItemID
                LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
                LEFT OUTER JOIN Account a ON a.ID = p.AccountID
            ) p
        WHERE
            DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period

    -- Opening balance
    UNION ALL
    SELECT
        0 AS RowNumber
        , 3 AS [Level]
        , N''Opening Balance'' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N''Opening Balance'' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, d.[Date]) AS Period
            , SUM(p.[Sum]) AS [Sum]
        FROM
            (
            SELECT
                p.ID
                , p.[Date]
                , p.[Sum]
                , a.Name AS AccountName
                , c.Name AS CompanyName
                , i.Name AS ItemName
                , p.Comment
            FROM
                Payment p
                LEFT OUTER JOIN Item i ON i.ID = p.ItemID
                LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
                LEFT OUTER JOIN Account a ON a.ID = p.AccountID
            ) p
            CROSS JOIN (
                SELECT DATEADD(YEAR, @Year - 1900, 0) AS [Date]
                UNION SELECT DATEADD(MONTH, 1, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 2, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 3, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 4, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 5, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 6, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 7, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 8, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 9, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 10, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 11, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
            ) d
        WHERE
            p.[Date] < d.[Date]
        GROUP BY
            d.[Date]
        ) p
    GROUP BY
        p.Period

    -- Closing balance
    UNION ALL
    SELECT
        4 AS RowNumber
        , 3 AS [Level]
        , N''Closing Balance'' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N''Closing Balance'' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, d.[Date]) AS Period
            , SUM(p.[Sum]) AS [Sum]
        FROM
            (
            SELECT
                p.ID
                , p.[Date]
                , p.[Sum]
                , a.Name AS AccountName
                , c.Name AS CompanyName
                , i.Name AS ItemName
                , p.Comment
            FROM
                Payment p
                LEFT OUTER JOIN Item i ON i.ID = p.ItemID
                LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
                LEFT OUTER JOIN Account a ON a.ID = p.AccountID
            ) p
            CROSS JOIN (
                SELECT DATEADD(MONTH, 1, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 2, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 3, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 4, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 5, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 6, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 7, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 8, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 9, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 10, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 11, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 12, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
            ) d
        WHERE
            p.[Date] < d.[Date]
        GROUP BY
            d.[Date]
        ) p
    GROUP BY
        p.Period
    ) p
    LEFT OUTER JOIN ColumnTranslation t ON t.TABLE_NAME = ''ItemName'' AND t.COLUMN_NAME = p.Name
        AND UPPER(t.LANGUAGE_NAME) = UPPER(@DataLanguage)
GROUP BY
    p.RowNumber,
    p.ItemType,
    p.ItemName,
    p.CompanyName
ORDER BY
    p.RowNumber,
    p.ItemType,
    p.ItemName,
    p.CompanyName',N'CashFlow',N'CODE',NULL,NULL,NULL);
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES (N'SELECT
    p.RowNumber AS N
    , MAX(p.[Level]) AS [Level]
    , p.ItemType
    , p.ItemName
    , p.CompanyName
    , COALESCE(MAX(t.TRANSLATED_NAME), MAX(p.Name)) AS Name
    , SUM(p.Total) AS Total
    , SUM(p.Jan) AS Jan
    , SUM(p.Feb) AS Feb
    , SUM(p.Mar) AS Mar
    , SUM(p.Apr) AS Apr
    , SUM(p.May) AS May
    , SUM(p.Jun) AS Jun
    , SUM(p.Jul) AS Jul
    , SUM(p.Aug) AS Aug
    , SUM(p.Sep) AS Sep
    , SUM(p.Oct) AS Oct
    , SUM(p.Nov) AS Nov
    , SUM(p.[Dec]) AS [Dec]
FROM
    (
    -- Total Items
    SELECT
        p.RowNumber
        , 1 AS [Level]
        , p.ItemType
        , p.ItemName
        , NULL AS CompanyName
        , p.ItemName AS [Name]
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N''Expences'' ELSE N''Income'' END AS NVARCHAR(50)) AS ItemType
            , p.ItemName
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            (
            SELECT
                p.ID
                , p.[Date]
                , p.[Sum]
                , a.Name AS AccountName
                , c.Name AS CompanyName
                , i.Name AS ItemName
                , p.Comment
            FROM
                Payment p
                LEFT OUTER JOIN Item i ON i.ID = p.ItemID
                LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
                LEFT OUTER JOIN Account a ON a.ID = p.AccountID
            ) p
        WHERE
            p.ItemName IS NOT NULL
            AND DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType,
        p.ItemName

    -- Total Income/Expenses
    UNION ALL
    SELECT
        p.RowNumber
        , 2 AS [Level]
        , p.ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N''Total '' + p.ItemType AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N''Expences'' ELSE N''Income'' END AS NVARCHAR(50)) AS ItemType
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            (
            SELECT
                p.ID
                , p.[Date]
                , p.[Sum]
                , a.Name AS AccountName
                , c.Name AS CompanyName
                , i.Name AS ItemName
                , p.Comment
            FROM
                Payment p
                LEFT OUTER JOIN Item i ON i.ID = p.ItemID
                LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
                LEFT OUTER JOIN Account a ON a.ID = p.AccountID
            ) p
        WHERE
            DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType

    -- Net Chanhge
    UNION ALL
    SELECT
        3 AS RowNumber
        , 2 AS [Level]
        , N''Net Change'' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N''Net Change'' AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            (
            SELECT
                p.ID
                , p.[Date]
                , p.[Sum]
                , a.Name AS AccountName
                , c.Name AS CompanyName
                , i.Name AS ItemName
                , p.Comment
            FROM
                Payment p
                LEFT OUTER JOIN Item i ON i.ID = p.ItemID
                LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
                LEFT OUTER JOIN Account a ON a.ID = p.AccountID
            ) p
        WHERE
            DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period

    -- Opening balance
    UNION ALL
    SELECT
        0 AS RowNumber
        , 3 AS [Level]
        , N''Opening Balance'' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N''Opening Balance'' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, d.[Date]) AS Period
            , SUM(p.[Sum]) AS [Sum]
        FROM
            (
            SELECT
                p.ID
                , p.[Date]
                , p.[Sum]
                , a.Name AS AccountName
                , c.Name AS CompanyName
                , i.Name AS ItemName
                , p.Comment
            FROM
                Payment p
                LEFT OUTER JOIN Item i ON i.ID = p.ItemID
                LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
                LEFT OUTER JOIN Account a ON a.ID = p.AccountID
            ) p
            CROSS JOIN (
                SELECT DATEADD(YEAR, @Year - 1900, 0) AS [Date]
                UNION SELECT DATEADD(MONTH, 1, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 2, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 3, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 4, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 5, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 6, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 7, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 8, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 9, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 10, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 11, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
            ) d
        WHERE
            p.[Date] < d.[Date]
        GROUP BY
            d.[Date]
        ) p
    GROUP BY
        p.Period

    -- Closing balance
    UNION ALL
    SELECT
        4 AS RowNumber
        , 3 AS [Level]
        , N''Closing Balance'' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N''Closing Balance'' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, d.[Date]) AS Period
            , SUM(p.[Sum]) AS [Sum]
        FROM
            (
            SELECT
                p.ID
                , p.[Date]
                , p.[Sum]
                , a.Name AS AccountName
                , c.Name AS CompanyName
                , i.Name AS ItemName
                , p.Comment
            FROM
                Payment p
                LEFT OUTER JOIN Item i ON i.ID = p.ItemID
                LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
                LEFT OUTER JOIN Account a ON a.ID = p.AccountID
            ) p
            CROSS JOIN (
                SELECT DATEADD(MONTH, 1, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 2, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 3, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 4, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 5, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 6, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 7, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 8, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 9, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 10, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 11, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 12, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
            ) d
        WHERE
            p.[Date] < d.[Date]
        GROUP BY
            d.[Date]
        ) p
    GROUP BY
        p.Period
    ) p
    LEFT OUTER JOIN ColumnTranslation t ON t.TABLE_NAME = ''ItemName'' AND t.COLUMN_NAME = p.Name
        AND UPPER(t.LANGUAGE_NAME) = UPPER(@DataLanguage)
GROUP BY
    p.RowNumber,
    p.ItemType,
    p.ItemName,
    p.CompanyName
ORDER BY
    p.RowNumber,
    p.ItemType,
    p.ItemName,
    p.CompanyName',N'CashFlowSummary',N'CODE',NULL,NULL,NULL);
GO

INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,N'CashFlow',NULL,N'ContextMenu',N'SELECT
    p.ID
    , p.[Date]
    , p.[Sum]
    , a.Name AS AccountName
    , c.Name AS CompanyName
    , i.Name AS ItemName
    , p.Comment
FROM
    Payment p
    LEFT OUTER JOIN Item i ON i.ID = p.ItemID
    LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
    LEFT OUTER JOIN Account a ON a.ID = p.AccountID
WHERE
    c.Name = @CompanyName
',N'Payments - {CompanyName}',N'CODE',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,N'CashFlow',NULL,N'ContextMenu',N'SELECT
    p.ID
    , p.[Date]
    , p.[Sum]
    , a.Name AS AccountName
    , c.Name AS CompanyName
    , i.Name AS ItemName
    , p.Comment
FROM
    Payment p
    LEFT OUTER JOIN Item i ON i.ID = p.ItemID
    LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
    LEFT OUTER JOIN Account a ON a.ID = p.AccountID
WHERE
    i.Name = @ItemName
',N'Payments - {ItemName}',N'CODE',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,N'CashFlowSummary',NULL,N'ContextMenu',N'SELECT
    p.ID
    , p.[Date]
    , p.[Sum]
    , a.Name AS AccountName
    , c.Name AS CompanyName
    , i.Name AS ItemName
    , p.Comment
FROM
    Payment p
    LEFT OUTER JOIN Item i ON i.ID = p.ItemID
    LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
    LEFT OUTER JOIN Account a ON a.ID = p.AccountID
WHERE
    i.Name = @ItemName
',N'Payments - {ItemName}',N'CODE',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,N'Payments',NULL,N'ContextMenu',N'SELECT
    p.ID
    , p.[Date]
    , p.[Sum]
    , a.Name AS AccountName
    , c.Name AS CompanyName
    , i.Name AS ItemName
    , p.Comment
FROM
    Payment p
    LEFT OUTER JOIN Item i ON i.ID = p.ItemID
    LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
    LEFT OUTER JOIN Account a ON a.ID = p.AccountID
WHERE
    c.Name = @CompanyName
',N'Payments - {CompanyName}',N'CODE',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,N'Payments',NULL,N'ContextMenu',N'SELECT
    p.ID
    , p.[Date]
    , p.[Sum]
    , a.Name AS AccountName
    , c.Name AS CompanyName
    , i.Name AS ItemName
    , p.Comment
FROM
    Payment p
    LEFT OUTER JOIN Item i ON i.ID = p.ItemID
    LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
    LEFT OUTER JOIN Account a ON a.ID = p.AccountID
WHERE
    i.Name = @ItemName
',N'Payments - {ItemName}',N'CODE',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,N'Payments',NULL,N'ContextMenu',N'SELECT
    p.ID
    , p.[Date]
    , p.[Sum]
    , a.Name AS AccountName
    , c.Name AS CompanyName
    , i.Name AS ItemName
    , p.Comment
FROM
    Payment p
    LEFT OUTER JOIN Item i ON i.ID = p.ItemID
    LEFT OUTER JOIN Company c ON c.ID = p.CompanyID
    LEFT OUTER JOIN Account a ON a.ID = p.AccountID
WHERE
    p.[Date] = @Date
    ',N'Payments - {Date}',N'CODE',NULL,13,NULL);
GO

INSERT INTO [ParameterValues] ([SPECIFIC_SCHEMA],[SPECIFIC_NAME],[PARAMETER_NAME],[SELECT_SCHEMA],[SELECT_NAME],[SELECT_TYPE]) VALUES (NULL,N'CashFlow',N'Year',N'SELECT DISTINCT DATEPART(YEAR, [Date]) AS [Year] FROM Payment WHERE [Date] > ''20111231'' ORDER BY DATEPART(YEAR, [Date]) DESC',N'PaymentsYear',N'CODE');
GO
INSERT INTO [ParameterValues] ([SPECIFIC_SCHEMA],[SPECIFIC_NAME],[PARAMETER_NAME],[SELECT_SCHEMA],[SELECT_NAME],[SELECT_TYPE]) VALUES (NULL,N'CashFlowSummary',N'Year',N'SELECT DISTINCT DATEPART(YEAR, [Date]) AS [Year] FROM Payment WHERE [Date] > ''20111231'' ORDER BY DATEPART(YEAR, [Date]) DESC',N'PaymentsYear',N'CODE');
GO
INSERT INTO [ParameterValues] ([SPECIFIC_SCHEMA],[SPECIFIC_NAME],[PARAMETER_NAME],[SELECT_SCHEMA],[SELECT_NAME],[SELECT_TYPE]) VALUES (NULL,N'Payments',N'AccountName',N'SELECT NULL AS Name UNION ALL SELECT Name FROM Account',N'AccountName',N'CODE');
GO
INSERT INTO [ParameterValues] ([SPECIFIC_SCHEMA],[SPECIFIC_NAME],[PARAMETER_NAME],[SELECT_SCHEMA],[SELECT_NAME],[SELECT_TYPE]) VALUES (NULL,N'Payments',N'CompanyName',N'SELECT NULL AS Name UNION ALL SELECT Name FROM Company',N'CompanyName',N'CODE');
GO
INSERT INTO [ParameterValues] ([SPECIFIC_SCHEMA],[SPECIFIC_NAME],[PARAMETER_NAME],[SELECT_SCHEMA],[SELECT_NAME],[SELECT_TYPE]) VALUES (NULL,N'Payments',N'ItemName',N'SELECT NULL AS Name UNION ALL SELECT Name FROM Item',N'ItemName',N'CODE');
GO

INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,N'Payments - {CompanyName}',N'en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,N'Payments - {ItemName}',N'en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,N'Payments - {Date}',N'en',NULL,NULL,NULL);
GO

INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,N'ItemName',N'Opening Balance',N'en',N'Opening Balance',NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,N'ItemName',N'Total Income',N'en',N'Total Income',NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,N'ItemName',N'Revenue',N'en',N'Revenue',NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,N'ItemName',N'Total Expences',N'en',N'Total Expences',NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,N'ItemName',N'Expenses',N'en',N'Expenses',NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,N'ItemName',N'Payroll',N'en',N'Payroll',NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,N'ItemName',N'Taxes',N'en',N'Taxes',NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,N'ItemName',N'Net Change',N'en',N'Net Change',NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,N'ItemName',N'Closing Balance',N'en',N'Closing Balance',NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,N'Payments',N'Sum',N'en',N'Amount',NULL);
GO

INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,N'Payments',N'<?xml version="1.0" encoding="Unicode"?>
<table name="Payments">
<columnFormats>
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$4" type="String" />
<column name="ID" property="ColumnWidth" value="0.08" type="Double" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$D$4" type="String" />
<column name="Date" property="ColumnWidth" value="10" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sum" property="Address" value="$E$4" type="String" />
<column name="Sum" property="ColumnWidth" value="11.71" type="Double" />
<column name="Sum" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="AccountName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="AccountName" property="Address" value="$F$4" type="String" />
<column name="AccountName" property="ColumnWidth" value="15.57" type="Double" />
<column name="CompanyName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="CompanyName" property="Address" value="$G$4" type="String" />
<column name="CompanyName" property="ColumnWidth" value="16.71" type="Double" />
<column name="ItemName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ItemName" property="Address" value="$H$4" type="String" />
<column name="ItemName" property="ColumnWidth" value="17.71" type="Double" />
<column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Comment" property="Address" value="$I$4" type="String" />
<column name="Comment" property="ColumnWidth" value="21.71" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="ID" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,N'CashFlow',N'<?xml version="1.0" encoding="Unicode"?>
<table name="CashFlow">
<columnFormats>
<column name="" property="ListObjectName" value="CashFlow_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$5" type="String" />
<column name="N" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="N" property="Address" value="$C$5" type="String" />
<column name="Level" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Level" property="Address" value="$D$5" type="String" />
<column name="ItemType" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemType" property="Address" value="$E$5" type="String" />
<column name="ItemName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemName" property="Address" value="$F$5" type="String" />
<column name="CompanyName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="CompanyName" property="Address" value="$G$5" type="String" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name" property="Address" value="$H$5" type="String" />
<column name="Name" property="ColumnWidth" value="27.86" type="Double" />
<column name="Total" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Total" property="Address" value="$I$5" type="String" />
<column name="Total" property="ColumnWidth" value="13.14" type="Double" />
<column name="Total" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jan" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jan" property="Address" value="$J$5" type="String" />
<column name="Jan" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jan" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Feb" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Feb" property="Address" value="$K$5" type="String" />
<column name="Feb" property="ColumnWidth" value="10.71" type="Double" />
<column name="Feb" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Mar" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mar" property="Address" value="$L$5" type="String" />
<column name="Mar" property="ColumnWidth" value="10.71" type="Double" />
<column name="Mar" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Apr" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Apr" property="Address" value="$M$5" type="String" />
<column name="Apr" property="ColumnWidth" value="10.71" type="Double" />
<column name="Apr" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="May" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="May" property="Address" value="$N$5" type="String" />
<column name="May" property="ColumnWidth" value="10.71" type="Double" />
<column name="May" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jun" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jun" property="Address" value="$O$5" type="String" />
<column name="Jun" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jun" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jul" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jul" property="Address" value="$P$5" type="String" />
<column name="Jul" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jul" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Aug" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Aug" property="Address" value="$Q$5" type="String" />
<column name="Aug" property="ColumnWidth" value="10.71" type="Double" />
<column name="Aug" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Sep" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sep" property="Address" value="$R$5" type="String" />
<column name="Sep" property="ColumnWidth" value="10.71" type="Double" />
<column name="Sep" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Oct" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Oct" property="Address" value="$S$5" type="String" />
<column name="Oct" property="ColumnWidth" value="10.71" type="Double" />
<column name="Oct" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Nov" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Nov" property="Address" value="$T$5" type="String" />
<column name="Nov" property="ColumnWidth" value="10.71" type="Double" />
<column name="Nov" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Dec" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Dec" property="Address" value="$U$5" type="String" />
<column name="Dec" property="ColumnWidth" value="10.71" type="Double" />
<column name="Dec" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$5:$U$21" type="String" />
<column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Formula1" value="=$D5=3" type="String" />
<column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="_RowNum" property="FormatConditions(2).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(2).AppliesTo.Address" value="$B$5:$U$21" type="String" />
<column name="_RowNum" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Priority" value="5" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Formula1" value="=$D5=1" type="String" />
<column name="_RowNum" property="FormatConditions(2).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(2).Interior.Color" value="15853276" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.ThemeColor" value="5" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.TintAndShade" value="0.799981688894314" type="Double" />
<column name="_RowNum" property="FormatConditions(3).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).AppliesTo.Address" value="$B$5:$U$21" type="String" />
<column name="_RowNum" property="FormatConditions(3).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Priority" value="6" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Formula1" value="=$D5=2" type="String" />
<column name="_RowNum" property="FormatConditions(3).Font.Color" value="16777215" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.ThemeColor" value="1" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).Interior.Color" value="6299648" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="7" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,N'CashFlowSummary',N'<?xml version="1.0" encoding="Unicode"?>
<table name="CashFlowSummary">
<columnFormats>
<column name="" property="ListObjectName" value="CashFlow_Table134" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$5" type="String" />
<column name="N" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="N" property="Address" value="$C$5" type="String" />
<column name="Level" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Level" property="Address" value="$D$5" type="String" />
<column name="ItemType" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemType" property="Address" value="$E$5" type="String" />
<column name="ItemName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemName" property="Address" value="$F$5" type="String" />
<column name="CompanyName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="CompanyName" property="Address" value="$G$5" type="String" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name" property="Address" value="$H$5" type="String" />
<column name="Name" property="ColumnWidth" value="27.86" type="Double" />
<column name="Total" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Total" property="Address" value="$I$5" type="String" />
<column name="Total" property="ColumnWidth" value="13.14" type="Double" />
<column name="Total" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jan" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jan" property="Address" value="$J$5" type="String" />
<column name="Jan" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jan" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Feb" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Feb" property="Address" value="$K$5" type="String" />
<column name="Feb" property="ColumnWidth" value="11" type="Double" />
<column name="Feb" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Mar" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mar" property="Address" value="$L$5" type="String" />
<column name="Mar" property="ColumnWidth" value="10.71" type="Double" />
<column name="Mar" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Apr" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Apr" property="Address" value="$M$5" type="String" />
<column name="Apr" property="ColumnWidth" value="10.71" type="Double" />
<column name="Apr" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="May" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="May" property="Address" value="$N$5" type="String" />
<column name="May" property="ColumnWidth" value="10.71" type="Double" />
<column name="May" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jun" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jun" property="Address" value="$O$5" type="String" />
<column name="Jun" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jun" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jul" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jul" property="Address" value="$P$5" type="String" />
<column name="Jul" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jul" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Aug" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Aug" property="Address" value="$Q$5" type="String" />
<column name="Aug" property="ColumnWidth" value="10.71" type="Double" />
<column name="Aug" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Sep" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sep" property="Address" value="$R$5" type="String" />
<column name="Sep" property="ColumnWidth" value="10.71" type="Double" />
<column name="Sep" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Oct" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Oct" property="Address" value="$S$5" type="String" />
<column name="Oct" property="ColumnWidth" value="10.71" type="Double" />
<column name="Oct" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Nov" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Nov" property="Address" value="$T$5" type="String" />
<column name="Nov" property="ColumnWidth" value="10.71" type="Double" />
<column name="Nov" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Dec" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Dec" property="Address" value="$U$5" type="String" />
<column name="Dec" property="ColumnWidth" value="10.71" type="Double" />
<column name="Dec" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$5:$U$13" type="String" />
<column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Formula1" value="=$D5=3" type="String" />
<column name="_RowNum" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="_RowNum" property="FormatConditions(2).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(2).AppliesTo.Address" value="$B$5:$U$13" type="String" />
<column name="_RowNum" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Priority" value="5" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Formula1" value="=$D5=1" type="String" />
<column name="_RowNum" property="FormatConditions(2).Interior.Color" value="16777215" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.Pattern" value="-4142" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.PatternThemeColor" value="-4142" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.ThemeColor" value="-4142" type="Double" />
<column name="_RowNum" property="FormatConditions(3).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).AppliesTo.Address" value="$B$5:$U$13" type="String" />
<column name="_RowNum" property="FormatConditions(3).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Priority" value="6" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Formula1" value="=$D5=2" type="String" />
<column name="_RowNum" property="FormatConditions(3).Font.Color" value="16777215" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.ThemeColor" value="1" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).Interior.Color" value="6299648" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="7" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
</table>
');
GO

-- print Payment Register Application has been installed
