Attribute VB_Name = "Module1"
Option Explicit

' =========================================================
' Refreshes data validation lists
' =========================================================

Sub RefreshLists()

On Error Resume Next

' Refreshing lists

Worksheets("Accounts").ListObjects(1).Refresh
Worksheets("Companies").ListObjects(2).Refresh
Worksheets("Items").ListObjects(3).Refresh

' Refreshing data and configuration on the Payments sheet

Call ReloadPaymentParameters

End Sub


' =========================================================
' Adds a payment to a database
' =========================================================

Sub AddPayment()

On Error Resume Next

Dim screenUpdating As Boolean
screenUpdating = Application.screenUpdating

Application.screenUpdating = False

Dim wb As Workbook
Dim ws As Worksheet
Dim ts As Worksheet
Dim lo As ListObject

Set wb = ActiveWorkbook
Set ws = wb.Sheets("Form")
Set ts = wb.Sheets("Payments")
Set lo = ts.ListObjects(1)

Dim lastRow As Long
Dim col As ListColumn
Dim r As Range

' Adding a new row to the Excel table connected to a database
' and copiyng values from the form to the table

' This example technique shows how to copy values for all table columns
' The form must contain named cells with the database table column names
' In the table and view examples:  Date, Sum, AccountID, CompanyID, ItemID, Comment
' In the stored procedure example: Date, Sum, AccountName, CompanyName, ItemName, Comment
' The _RowNum and ID columns are skipped
' Use Formulas, Name Manager to add names for data cells

If lo.Range.Rows.Count = 0 Then
    lastRow = lo.Range.Row + 1
Else
    lastRow = lo.Range.Row + lo.Range.Rows.Count
End If

For Each col In lo.ListColumns
    
    If col.Name = "_RowNum" Or col.Name = "ID" Then
    Else
        Set r = ws.Range(col.Name)
        ts.Cells(lastRow, col.Range.Column).Value = r.Value
    End If
Next

' Getting a reference to the SaveToDB add-in
' The SaveToDB add-in must be installed

Dim addIn As COMAddIn
Dim automationObject As Object
Set addIn = Application.COMAddIns("SaveToDB")
Set automationObject = addIn.Object

' Saving Excel table changes to a database table
' This action is the same as a click on the Save button

ts.Select
automationObject.Save
ws.Select

' Reloading data using the form parameters
' ReloadFilteredPaymentsByID is used in the example with tables and views
' ReloadFilteredPaymentsByName is used in the example with stored procedures

' Call ReloadFilteredPaymentsByID
Call ReloadFilteredPaymentsByName

Application.screenUpdating = screenUpdating

End Sub


' =========================================================
' Reloads data from a database using the form ID parameters
' =========================================================

Sub ReloadFilteredPaymentsByID()

On Error Resume Next

Dim screenUpdating As Boolean
screenUpdating = Application.screenUpdating

Application.screenUpdating = False

Dim wb As Workbook
Dim ws As Worksheet
Dim ts As Worksheet
Dim lo As ListObject

Set wb = ActiveWorkbook
Set ws = wb.Sheets("Form")
Set ts = wb.Sheets("Payments")
Set lo = ts.ListObjects(1)

' If all the parameter values are equal then exit without reload

If ts.Range("AccountID").Value = ws.Range("AccountID").Value _
    And ts.Range("CompanyID").Value = ws.Range("CompanyID").Value _
    And ts.Range("ItemID").Value = ws.Range("ItemID").Value Then
    Exit Sub
End If

' Getting a reference to the SaveToDB add-in
' The SaveToDB add-in must be installed

Dim addIn As COMAddIn
Dim automationObject As Object
Set addIn = Application.COMAddIns("SaveToDB")
Set automationObject = addIn.Object

' Changing named cell values on the Payments sheet to the form values
' These named cells are used as database query parameters
' Such parameters are shown on the ribbon also and can be configured
' The changing is made without firing events to prevent reloading data on each step
' To update the query with new parameter values,
' the RebuildCommandTextFromNamedCells method is used, on the selected Payments sheet

Application.EnableEvents = False

ts.Range("AccountID").Value = ws.Range("AccountID").Value
ts.Range("CompanyID").Value = ws.Range("CompanyID").Value
ts.Range("ItemID").Value = ws.Range("ItemID").Value

Application.EnableEvents = True

ts.Select
automationObject.RebuildCommandTextFromNamedCells
ws.Select

Application.screenUpdating = screenUpdating

End Sub


' =========================================================
' Reloads data from a database using the form name parameters
' =========================================================

Sub ReloadFilteredPaymentsByName()

On Error Resume Next

Dim screenUpdating As Boolean
screenUpdating = Application.screenUpdating

Application.screenUpdating = False

Dim wb As Workbook
Dim ws As Worksheet
Dim ts As Worksheet
Dim lo As ListObject

Set wb = ActiveWorkbook
Set ws = wb.Sheets("Form")
Set ts = wb.Sheets("Payments")
Set lo = ts.ListObjects(1)

' If all the parameter values are equal then exit without reload

If ts.Range("AccountName").Value = ws.Range("AccountName").Value _
    And ts.Range("CompanyName").Value = ws.Range("CompanyName").Value _
    And ts.Range("ItemName").Value = ws.Range("ItemName").Value Then
    Exit Sub
End If

' Getting a reference to the SaveToDB add-in
' The SaveToDB add-in must be installed

Dim addIn As COMAddIn
Dim automationObject As Object
Set addIn = Application.COMAddIns("SaveToDB")
Set automationObject = addIn.Object

' Changing named cell values on the Payments sheet to the form values
' These named cells are used as database query parameters
' Such parameters are shown on the ribbon also and can be configured
' The changing is made without firing events to prevent reloading data on each step
' To update the query with new parameter values,
' the RebuildCommandTextFromNamedCells method is used, on the selected Payments sheet

Application.EnableEvents = False

ts.Range("AccountName").Value = ws.Range("AccountName").Value
ts.Range("CompanyName").Value = ws.Range("CompanyName").Value
ts.Range("ItemName").Value = ws.Range("ItemName").Value

Application.EnableEvents = True

ts.Select
automationObject.RebuildCommandTextFromNamedCells
ws.Select

Application.screenUpdating = screenUpdating

End Sub


' =========================================================
' Reloads data and configuration from a database
' =========================================================

Sub ReloadPaymentParameters()

On Error Resume Next

Dim screenUpdating As Boolean
screenUpdating = Application.screenUpdating

Application.screenUpdating = False

Dim wb As Workbook
Dim ws As Worksheet
Dim ts As Worksheet

Set wb = ActiveWorkbook
Set ws = ActiveSheet
Set ts = wb.Sheets("Payments")

' Getting a reference to the SaveToDB add-in
' The SaveToDB add-in must be installed

Dim addIn As COMAddIn
Dim automationObject As Object
Set addIn = Application.COMAddIns("SaveToDB")
Set automationObject = addIn.Object

' Reloading data and configurations

ts.Select
automationObject.Load
ws.Select

Application.screenUpdating = screenUpdating

End Sub
