﻿
-- This code updates Contacts as the record must be in the table

UPDATE [Contacts]
SET
    [ContactCategory] = @ContactCategory
    , [String1] = @String1
    , [String2] = @String2
    , [String3] = @String3
    , [Number1] = @Number1
    , [Number2] = @Number2
    , [Number3] = @Number3
WHERE
    ID = @ID;
GO

-- The code below has UPDATE and INSERT commands
-- UPDATE is used to update existing data with any value
-- INSERT is used to insert new non-NULL values

-- Contact tables: Names, Emails, Mobile, Phone, Company, JobTitle, Country, Website
-- These tables are separate to make possible to update tables using nested queries as
-- SQLCE does not support the FROM clause for UPDATE and supports it for INSERT.

UPDATE [ContactNames]
SET
    [FirstName] = @FirstName
    ,[LastName] = @LastName
WHERE
    ID = @ID;
GO

INSERT INTO [ContactNames]
    ( [ID]
    , [FirstName]
    , [LastName]
    )
SELECT
    s.[ID]
    , s.[FirstName]
    , s.[LastName]
FROM
    (
    SELECT
        @ID AS ID
        , @FirstName AS FirstName
        , @LastName AS LastName
    ) s
    LEFT OUTER JOIN [ContactNames] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND c.ID IS NULL;
GO

UPDATE [ContactEmail]
SET
    [Email] = @Email
WHERE
    ID = @ID;
GO

INSERT INTO [ContactEmail]
    ( [ID]
    , [Email]
    )
SELECT
    s.[ID]
    , s.[Email]
FROM
    (
    SELECT
        @ID AS ID
        , @Email AS Email
    ) s
    LEFT OUTER JOIN [ContactEmail] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Email IS NOT NULL
    AND c.ID IS NULL;
GO
    
UPDATE [ContactMobile]
SET
    [Mobile] = @Mobile
WHERE
    ID = @ID;
GO

INSERT INTO [ContactMobile]
    ( [ID]
    , [Mobile]
    )
SELECT
    s.[ID]
    , s.[Mobile]
FROM
    (
    SELECT
        @ID AS ID
        , @Mobile AS Mobile
    ) s
    LEFT OUTER JOIN [ContactMobile] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Mobile IS NOT NULL
    AND c.ID IS NULL;
GO

UPDATE [ContactPhone]
SET
    [Phone] = @Phone
WHERE
    ID = @ID;
GO

INSERT INTO [ContactPhone]
    ( [ID]
    , [Phone]
    )
SELECT
    s.[ID]
    , s.[Phone]
FROM
    (
    SELECT
        @ID AS ID
        , @Phone AS Phone
    ) s
    LEFT OUTER JOIN [ContactPhone] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Phone IS NOT NULL
    AND c.ID IS NULL;
GO
    
UPDATE [ContactCompany]
SET
    [Company] = @Company
WHERE
    ID = @ID;
GO

INSERT INTO [ContactCompany]
    ( [ID]
    , [Company]
    )
SELECT
    s.[ID]
    , s.[Company]
FROM
    (
    SELECT
        @ID AS ID
        , @Company AS Company
    ) s
    LEFT OUTER JOIN [ContactCompany] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Company IS NOT NULL
    AND c.ID IS NULL;
GO

UPDATE [ContactJobTitle]
SET
    [JobTitle] = @JobTitle
WHERE
    ID = @ID;
GO

INSERT INTO [ContactJobTitle]
    ( [ID]
    , [JobTitle]
    )
SELECT
    s.[ID]
    , s.[JobTitle]
FROM
    (
    SELECT
        @ID AS ID
        , @JobTitle AS JobTitle
    ) s
    LEFT OUTER JOIN [ContactJobTitle] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.JobTitle IS NOT NULL
    AND c.ID IS NULL;
GO

UPDATE [ContactCountry]
SET
    [Country] = @Country
WHERE
    ID = @ID;
GO

INSERT INTO [ContactCountry]
    ( [ID]
    , [Country]
    )
SELECT
    s.[ID]
    , s.[Country]
FROM
    (
    SELECT
        @ID AS ID
        , @Country AS Country
    ) s
    LEFT OUTER JOIN [ContactCountry] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Country IS NOT NULL
    AND c.ID IS NULL;
GO
    
UPDATE [ContactWebsite]
SET
    [Website] = @Website
WHERE
    ID = @ID;
GO

INSERT INTO [ContactWebsite]
    ( [ID]
    , [Website]
    )
SELECT
    s.[ID]
    , s.[Website]
FROM
    (
    SELECT
        @ID AS ID
        , @Website AS Website
    ) s
    LEFT OUTER JOIN [ContactWebsite] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Website IS NOT NULL
    AND c.ID IS NULL;
GO