-- Web Finance Database
-- July 15, 2014

-- This SQL code must be executed after SaveToDB Framework installation!

CREATE TABLE [StockTradeHistory] (
    [Symbol] nvarchar(50) NOT NULL, 
    [Date] datetime NOT NULL, 
    [Open] float, 
    [High] float, 
    [Low] float, 
    [Close] float, 
    [Volume] int,
    CONSTRAINT [PK_StockTradeHistory] PRIMARY KEY ([Symbol], [Date])
);
GO

CREATE TABLE [QueryListDB](
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [ntext] NULL,
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [TABLE_TYPE] [nvarchar](128) NULL,
    [INSERT_PROCEDURE] [ntext] NULL,
    [UPDATE_PROCEDURE] [ntext] NULL,
    [DELETE_PROCEDURE] [ntext] NULL,
 CONSTRAINT [PK_QueryListDB] PRIMARY KEY
(
    [ID]
)
);
GO
CREATE UNIQUE INDEX [QueryListDB_TableName]
    ON [QueryListDB] (
    [TABLE_NAME]
);
GO

INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('http://finance.yahoo.com/q/hp?s={Symbol=YHOO}+Historical+Prices','Historical Prices Yahoo HTML','HTTP',NULL,NULL,NULL);
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('http://ichart.finance.yahoo.com/table.csv?s={Symbol=YHOO}&ignore=.csv','Historical Prices Yahoo CSV','HTTP',NULL,NULL,NULL);
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('http://www.google.com/finance/historical?q={Symbol=GOOG}','Historical Prices Google HTML','HTTP','StockTradeHistory','StockTradeHistory','StockTradeHistory');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('http://www.google.com/finance/historical?q={Symbol=GOOG}&output=csv','Historical Prices Google CSV','HTTP','StockTradeHistory','StockTradeHistory','StockTradeHistory');
GO

INSERT INTO [QueryListDB] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('SELECT
    CASE sh1.Symbol
        WHEN ''COMP'' THEN ''Indice''
        WHEN ''SPX'' THEN ''Indice''
        WHEN ''DJX'' THEN ''Indice''
        ELSE ''Stock''
        END AS [Type]
    , sh1.Symbol
    , sh2.[Date] AS StartDate
    , sh3.[Date] AS LastDate
    , sh2.[Close] AS StartPrice
    , sh1.[High]
    , sh1.[Low]
    , sh3.[Close] AS LastPrice
    , CAST(sh3.[Close] - sh2.[Close] AS money) AS Change
    , CAST(sh3.[Close] / sh2.[Close] - 1 AS money) AS [Chg,%]
FROM
    (
    -- Start dates can be different for different stocks
    SELECT
        sh1.Symbol
        , sh1.[Date]
        , sh1.[Close]
    FROM
        StockTradeHistory sh1
        INNER JOIN
        (
        SELECT Symbol, MIN([Date]) AS [Date] FROM StockTradeHistory WHERE [Date] >= COALESCE(@StartDate, ''20130101'') GROUP BY Symbol
        ) sh2 ON sh2.Symbol = sh1.Symbol AND sh2.[Date] = sh1.[Date]
    ) sh2
    INNER JOIN
    (
    -- Last dates can be different for different stocks
    SELECT
        sh1.Symbol
        , sh1.[Date]
        , sh1.[Close]
    FROM
        StockTradeHistory sh1
        INNER JOIN
        (
        SELECT Symbol, MAX([Date]) AS [Date] FROM StockTradeHistory WHERE [Date] <= COALESCE(@EndDate, ''20201231'') GROUP BY Symbol
        ) sh2 ON sh2.Symbol = sh1.Symbol AND sh2.[Date] = sh1.[Date]
    ) sh3 ON sh3.Symbol = sh2.Symbol
    INNER JOIN
    (
    -- High, Low
    SELECT
        sh1.Symbol
        , MAX(sh1.[High] / sh1.[Close] * sh1.[Close]) AS [High]
        , MIN(sh1.[Low]  / sh1.[Close] * sh1.[Close]) AS [Low]
    FROM
        StockTradeHistory sh1
    WHERE
        sh1.[Date] BETWEEN COALESCE(@StartDate, ''20130101'') AND COALESCE(@EndDate, ''20201231'')
    GROUP BY
        sh1.Symbol
    ) sh1 ON sh1.Symbol = sh2.Symbol
ORDER BY
    [Type]
    , sh1.Symbol','Stock Performance','CODE',NULL,NULL,NULL);
GO

INSERT INTO [QueryListDB] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('SELECT * FROM StockTradeHistory WHERE Symbol = @Symbol','Historical Prices','CODE','StockTradeHistory','StockTradeHistory','StockTradeHistory');
GO

INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, N'QueryListDB', N'en', NULL, N'Configuration Table of Query List', N'The table defines configuration of Query List objects');
GO

INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryListDB', N'ID', N'en', NULL, NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryListDB', N'TABLE_SCHEMA', N'en', NULL, N'SQL-code or http-query');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryListDB', N'TABLE_NAME', N'en', NULL, N'Database object name or unique name for SQL-code and http-query');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryListDB', N'TABLE_TYPE', N'en', NULL, N'Database object type, CODE for SQL-code, or HTTP for http-query');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryListDB', N'INSERT_PROCEDURE', N'en', NULL, N'Destination table to save changes of SQL-codes');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryListDB', N'UPDATE_PROCEDURE', N'en', NULL, N'Destination table to save changes of SQL-codes');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryListDB', N'DELETE_PROCEDURE', N'en', NULL, N'Destination table to save changes of SQL-codes');
GO

INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, N'QueryListDB',NULL,N'Actions',N'http://www.savetodb.com/help4/configuring-query-list.htm',N'Online Help',N'HTTP',NULL,11,NULL);
GO

INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices',NULL,'Actions','http://www.google.com/finance/historical?q={Symbol=GOOG}','Open Stock at Google Finance','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices',NULL,'Actions','http://finance.yahoo.com/q/hp?s={Symbol=YHOO}+Historical+Prices','Open Stock at Yahoo! Finance','HTTP',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices',NULL,'Actions',NULL,'MenuSeparator1','MenuSeparator',NULL,20,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices',NULL,'Actions','DELETE FROM StockTradeHistory WHERE Symbol = @Symbol','Delete Stock Data','CODE','_Reload',21,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices Google CSV',NULL,'Actions','http://www.google.com/finance/historical?q={Symbol=GOOG}','Open Stock at Google Finance','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices Google CSV',NULL,'Actions','http://finance.yahoo.com/q/hp?s={Symbol=YHOO}+Historical+Prices','Open Stock at Yahoo! Finance','HTTP',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices Google HTML',NULL,'Actions','http://www.google.com/finance/historical?q={Symbol=GOOG}','Open Stock at Google Finance','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices Google HTML',NULL,'Actions','http://finance.yahoo.com/q/hp?s={Symbol=YHOO}+Historical+Prices','Open Stock at Yahoo! Finance','HTTP',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices Yahoo CSV',NULL,'Actions','http://www.google.com/finance/historical?q={Symbol=GOOG}','Open Stock at Google Finance','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices Yahoo CSV',NULL,'Actions','http://finance.yahoo.com/q/hp?s={Symbol=YHOO}+Historical+Prices','Open Stock at Yahoo! Finance','HTTP',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices Yahoo HTML',NULL,'Actions','http://www.google.com/finance/historical?q={Symbol=GOOG}','Open Stock at Google Finance','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Historical Prices Yahoo HTML',NULL,'Actions','http://finance.yahoo.com/q/hp?s={Symbol=YHOO}+Historical+Prices','Open Stock at Yahoo! Finance','HTTP',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Stock Performance',NULL,'ContextMenu','SELECT * FROM StockTradeHistory WHERE Symbol = @Symbol','Historical Prices','CODE','HistoricalPrices',1,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Stock Performance',NULL,'ContextMenu',NULL,'MenuSeparator1','MenuSeparator',NULL,10,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Stock Performance',NULL,'ContextMenu','http://www.google.com/finance/historical?q={Symbol=GOOG}','Open Stock at Google Finance','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Stock Performance',NULL,'ContextMenu','http://finance.yahoo.com/q/hp?s={Symbol=YHOO}+Historical+Prices','Open Stock at Yahoo! Finance','HTTP',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Stock Performance',NULL,'ContextMenu',NULL,'MenuSeparator2','MenuSeparator',NULL,20,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Stock Performance',NULL,'ContextMenu','DELETE FROM StockTradeHistory WHERE Symbol = @Symbol','Delete Stock Data','CODE','_Reload',21,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'StockTradeHistory',NULL,'Actions','http://www.google.com/finance/historical?q={Symbol=GOOG}','Open Stock at Google Finance','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'StockTradeHistory',NULL,'Actions','http://finance.yahoo.com/q/hp?s={Symbol=YHOO}+Historical+Prices','Open Stock at Yahoo! Finance','HTTP',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'StockTradeHistory',NULL,'Actions',NULL,'MenuSeparator1','MenuSeparator',NULL,20,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'StockTradeHistory',NULL,'Actions','DELETE FROM StockTradeHistory WHERE Symbol = @Symbol','Delete Stock Data','CODE','_Reload',21,NULL);
GO

INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Historical Prices Google CSV','<?xml version="1.0" encoding="Unicode"?>
<table name=".Historical Prices Google CSV">
<columnFormats>
<column name="" property="ListObjectName" value="WebFinance_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$C$4" type="String" />
<column name="Date" property="ColumnWidth" value="10" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="Address" value="$D$4" type="String" />
<column name="Open" property="ColumnWidth" value="7.86" type="Double" />
<column name="Open" property="NumberFormat" value="0.00" type="String" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="Address" value="$E$4" type="String" />
<column name="High" property="ColumnWidth" value="7.86" type="Double" />
<column name="High" property="NumberFormat" value="0.00" type="String" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="Address" value="$F$4" type="String" />
<column name="Low" property="ColumnWidth" value="7.86" type="Double" />
<column name="Low" property="NumberFormat" value="0.00" type="String" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="Address" value="$G$4" type="String" />
<column name="Close" property="ColumnWidth" value="7.86" type="Double" />
<column name="Close" property="NumberFormat" value="0.00" type="String" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="Address" value="$H$4" type="String" />
<column name="Chg" property="FormulaR1C1" value="=IF(R[1]C[-1]=0,0,[@Close]-R[1]C[-1])" type="String" />
<column name="Chg" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg" property="NumberFormat" value="0.00_ ;[Red]-0.00 " type="String" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="Address" value="$I$4" type="String" />
<column name="Chg,%" property="FormulaR1C1" value="=([@Chg]/([@Close]-[@Chg]))" type="String" />
<column name="Chg,%" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg,%" property="NumberFormat" value="0.00%" type="String" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="Address" value="$J$4" type="String" />
<column name="Volume" property="ColumnWidth" value="11.43" type="Double" />
<column name="Volume" property="NumberFormat" value="#,##0" type="String" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Volume Chg" property="Address" value="$K$4" type="String" />
<column name="Volume Chg" property="FormulaR1C1" value="=IF(R[1]C[-1]=0,0,[@Volume]-R[1]C[-1])" type="String" />
<column name="Volume Chg" property="NumberFormat" value="#,##0" type="String" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="VolChg,%" property="Address" value="$L$4" type="String" />
<column name="VolChg,%" property="FormulaR1C1" value="=[@[Volume Chg]]/([@Volume]-[@[Volume Chg]])" type="String" />
<column name="VolChg,%" property="ColumnWidth" value="11.43" type="Double" />
<column name="VolChg,%" property="NumberFormat" value="0%" type="String" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="Address" value="$M$4" type="String" />
<column name="PriceVolumeMark" property="FormulaR1C1" value="=IF([@[VolChg,%]]&#60;1%,&#34;&#34;,IF([@[Chg,%]]&#60;-1%,-1,IF([@[Chg,%]]&#62;1%,1,&#34;&#34;)))" type="String" />
<column name="PriceVolumeMark" property="ColumnWidth" value="2.14" type="Double" />
<column name="PriceVolumeMark" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="PriceVolumeMark" property="Font.Size" value="10" type="Double" />
<column name="Close" property="FormatConditions(1).AppliesTo.Address" value="$G$4:$G$253" type="String" />
<column name="Close" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Close" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="697.56" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="1078.14" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="Chg,%" property="FormatConditions(1).AppliesTo.Address" value="$I$4:$I$253" type="String" />
<column name="Chg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Chg,%" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.0226219273233422" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="0.137962848366881" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="Volume" property="FormatConditions(1).AppliesTo.Address" value="$J$4:$J$253" type="String" />
<column name="Volume" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="841931" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="11584258" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).AppliesTo.Address" value="$L$4:$L$253" type="String" />
<column name="VolChg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.76134721185629" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="1.72146739832665" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).AppliesTo.Address" value="$M$4:$M$253" type="String" />
<column name="PriceVolumeMark" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconSet.ID" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Up in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=1" type="String" />
</view>
<view name="Up or Down in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="&#60;&#62;" type="String" />
</view>
<view name="Down in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=-1" type="String" />
</view>
<view name="Top 10 Up">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="3" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
</view>
<view name="Top 10 Down">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="4" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Historical Prices Google HTML','<?xml version="1.0" encoding="Unicode"?>
<table name=".Historical Prices Google HTML">
<columnFormats>
<column name="" property="ListObjectName" value="WebFinance_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$C$4" type="String" />
<column name="Date" property="ColumnWidth" value="10.29" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="Address" value="$D$4" type="String" />
<column name="Open" property="ColumnWidth" value="7.86" type="Double" />
<column name="Open" property="NumberFormat" value="0.00" type="String" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="Address" value="$E$4" type="String" />
<column name="High" property="ColumnWidth" value="7.86" type="Double" />
<column name="High" property="NumberFormat" value="0.00" type="String" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="Address" value="$F$4" type="String" />
<column name="Low" property="ColumnWidth" value="7.86" type="Double" />
<column name="Low" property="NumberFormat" value="0.00" type="String" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="Address" value="$G$4" type="String" />
<column name="Close" property="ColumnWidth" value="7.86" type="Double" />
<column name="Close" property="NumberFormat" value="0.00" type="String" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="Address" value="$H$4" type="String" />
<column name="Chg" property="FormulaR1C1" value="=IF(R[1]C[-1]=0,0,[@Close]-R[1]C[-1])" type="String" />
<column name="Chg" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg" property="NumberFormat" value="0.00_ ;[Red]-0.00 " type="String" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="Address" value="$I$4" type="String" />
<column name="Chg,%" property="FormulaR1C1" value="=([@Chg]/([@Close]-[@Chg]))" type="String" />
<column name="Chg,%" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg,%" property="NumberFormat" value="0.00%" type="String" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="Address" value="$J$4" type="String" />
<column name="Volume" property="ColumnWidth" value="11.43" type="Double" />
<column name="Volume" property="NumberFormat" value="#,##0" type="String" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Volume Chg" property="Address" value="$K$4" type="String" />
<column name="Volume Chg" property="FormulaR1C1" value="=IF(R[1]C[-1]=0,0,[@Volume]-R[1]C[-1])" type="String" />
<column name="Volume Chg" property="NumberFormat" value="#,##0" type="String" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="VolChg,%" property="Address" value="$L$4" type="String" />
<column name="VolChg,%" property="FormulaR1C1" value="=[@[Volume Chg]]/([@Volume]-[@[Volume Chg]])" type="String" />
<column name="VolChg,%" property="ColumnWidth" value="11.43" type="Double" />
<column name="VolChg,%" property="NumberFormat" value="0%" type="String" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="Address" value="$M$4" type="String" />
<column name="PriceVolumeMark" property="FormulaR1C1" value="=IF([@[VolChg,%]]&#60;1%,&#34;&#34;,IF([@[Chg,%]]&#60;-1%,-1,IF([@[Chg,%]]&#62;1%,1,&#34;&#34;)))" type="String" />
<column name="PriceVolumeMark" property="ColumnWidth" value="2.14" type="Double" />
<column name="PriceVolumeMark" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="PriceVolumeMark" property="Font.Size" value="10" type="Double" />
<column name="Close" property="FormatConditions(1).AppliesTo.Address" value="$G$4:$G$33" type="String" />
<column name="Close" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Close" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="1007.95" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="1078.14" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="Chg,%" property="FormatConditions(1).AppliesTo.Address" value="$I$4:$I$33" type="String" />
<column name="Chg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Chg,%" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.0144707895380102" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="0.0209261083743842" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="Volume" property="FormatConditions(1).AppliesTo.Address" value="$J$4:$J$33" type="String" />
<column name="Volume" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="914624" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="2287182" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).AppliesTo.Address" value="$L$4:$L$33" type="String" />
<column name="VolChg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.508758376027793" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="0.836898003988524" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).AppliesTo.Address" value="$M$4:$M$33" type="String" />
<column name="PriceVolumeMark" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconSet.ID" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Up in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=1" type="String" />
</view>
<view name="Up or Down in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="&#60;&#62;" type="String" />
</view>
<view name="Down in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=-1" type="String" />
</view>
<view name="Top 10 Up">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="3" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
</view>
<view name="Top 10 Down">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="4" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Historical Prices Yahoo CSV','<?xml version="1.0" encoding="Unicode"?>
<table name=".Historical Prices Yahoo CSV">
<columnFormats>
<column name="" property="ListObjectName" value="WebFinance_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$C$4" type="String" />
<column name="Date" property="ColumnWidth" value="10" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="Address" value="$D$4" type="String" />
<column name="Open" property="ColumnWidth" value="7.86" type="Double" />
<column name="Open" property="NumberFormat" value="0.00" type="String" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="Address" value="$E$4" type="String" />
<column name="High" property="ColumnWidth" value="7.86" type="Double" />
<column name="High" property="NumberFormat" value="0.00" type="String" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="Address" value="$F$4" type="String" />
<column name="Low" property="ColumnWidth" value="7.86" type="Double" />
<column name="Low" property="NumberFormat" value="0.00" type="String" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="Address" value="$G$4" type="String" />
<column name="Close" property="ColumnWidth" value="7.86" type="Double" />
<column name="Close" property="NumberFormat" value="0.00" type="String" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="Address" value="$H$4" type="String" />
<column name="Volume" property="ColumnWidth" value="11.43" type="Double" />
<column name="Volume" property="NumberFormat" value="#,##0" type="String" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Volume Chg" property="Address" value="$I$4" type="String" />
<column name="Volume Chg" property="FormulaR1C1" value="=IF(R[1]C[-1]=0,0,[@Volume]-R[1]C[-1])" type="String" />
<column name="Volume Chg" property="NumberFormat" value="#,##0" type="String" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="VolChg,%" property="Address" value="$J$4" type="String" />
<column name="VolChg,%" property="FormulaR1C1" value="=[@[Volume Chg]]/([@Volume]-[@[Volume Chg]])" type="String" />
<column name="VolChg,%" property="ColumnWidth" value="11.43" type="Double" />
<column name="VolChg,%" property="NumberFormat" value="0%" type="String" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="Address" value="$K$4" type="String" />
<column name="PriceVolumeMark" property="FormulaR1C1" value="=IF([@[VolChg,%]]&#60;1%,&#34;&#34;,IF([@[Chg,%]]&#60;-1%,-1,IF([@[Chg,%]]&#62;1%,1,&#34;&#34;)))" type="String" />
<column name="PriceVolumeMark" property="ColumnWidth" value="2.14" type="Double" />
<column name="PriceVolumeMark" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="PriceVolumeMark" property="Font.Size" value="10" type="Double" />
<column name="Adj Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Adj Close" property="Address" value="$L$4" type="String" />
<column name="Adj Close" property="ColumnWidth" value="10.71" type="Double" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="Address" value="$M$4" type="String" />
<column name="Chg" property="FormulaR1C1" value="=IF(R[1]C[-1]=0,0,[@Close]-R[1]C[-1])" type="String" />
<column name="Chg" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg" property="NumberFormat" value="0.00_ ;[Red]-0.00 " type="String" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="Address" value="$N$4" type="String" />
<column name="Chg,%" property="FormulaR1C1" value="=([@Chg]/([@Close]-[@Chg]))" type="String" />
<column name="Chg,%" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg,%" property="NumberFormat" value="0.00%" type="String" />
<column name="Close" property="FormatConditions(1).AppliesTo.Address" value="$G$4:$G$2347" type="String" />
<column name="Close" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Close" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="100.01" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="1078.14" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="Volume" property="FormatConditions(1).AppliesTo.Address" value="$H$4:$H$2347" type="String" />
<column name="Volume" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="840900" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="41116700" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).AppliesTo.Address" value="$J$4:$J$2347" type="String" />
<column name="VolChg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.777590672865772" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="4.4264904705831" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).AppliesTo.Address" value="$K$4:$K$2347" type="String" />
<column name="PriceVolumeMark" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconSet.ID" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="Chg,%" property="FormatConditions(1).AppliesTo.Address" value="$N$4:$N$2347" type="String" />
<column name="Chg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Chg,%" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.11609131403118" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="0.199915469146238" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Up in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=1" type="String" />
</view>
<view name="Up or Down in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="&#60;&#62;" type="String" />
</view>
<view name="Down in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=-1" type="String" />
</view>
<view name="Top 10 Up">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="3" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
</view>
<view name="Top 10 Down">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="4" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Historical Prices Yahoo HTML','<?xml version="1.0" encoding="Unicode"?>
<table name=".Historical Prices Yahoo HTML">
<columnFormats>
<column name="" property="ListObjectName" value="WebFinance_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$C$4" type="String" />
<column name="Date" property="ColumnWidth" value="10.57" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="Address" value="$D$4" type="String" />
<column name="Open" property="ColumnWidth" value="7.86" type="Double" />
<column name="Open" property="NumberFormat" value="0.00" type="String" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="Address" value="$E$4" type="String" />
<column name="High" property="ColumnWidth" value="7.86" type="Double" />
<column name="High" property="NumberFormat" value="0.00" type="String" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="Address" value="$F$4" type="String" />
<column name="Low" property="ColumnWidth" value="7.86" type="Double" />
<column name="Low" property="NumberFormat" value="0.00" type="String" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="Address" value="$G$4" type="String" />
<column name="Close" property="ColumnWidth" value="7.86" type="Double" />
<column name="Close" property="NumberFormat" value="0.00" type="String" />
<column name="Adj Close*" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Adj Close*" property="Address" value="$H$4" type="String" />
<column name="Adj Close*" property="NumberFormat" value="0.00" type="String" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="Address" value="$I$4" type="String" />
<column name="Chg" property="FormulaR1C1" value="=IF(R[1]C[-2]=0,0,[@Close]-R[1]C[-2])" type="String" />
<column name="Chg" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg" property="NumberFormat" value="0.00_ ;[Red]-0.00 " type="String" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="Address" value="$J$4" type="String" />
<column name="Chg,%" property="FormulaR1C1" value="=([@Chg]/([@Close]-[@Chg]))" type="String" />
<column name="Chg,%" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg,%" property="NumberFormat" value="0.00%" type="String" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="Address" value="$K$4" type="String" />
<column name="Volume" property="ColumnWidth" value="11.43" type="Double" />
<column name="Volume" property="NumberFormat" value="#,##0" type="String" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Volume Chg" property="Address" value="$L$4" type="String" />
<column name="Volume Chg" property="FormulaR1C1" value="=IF(R[1]C[-1]=0,0,[@Volume]-R[1]C[-1])" type="String" />
<column name="Volume Chg" property="NumberFormat" value="#,##0" type="String" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="VolChg,%" property="Address" value="$M$4" type="String" />
<column name="VolChg,%" property="FormulaR1C1" value="=[@[Volume Chg]]/([@Volume]-[@[Volume Chg]])" type="String" />
<column name="VolChg,%" property="ColumnWidth" value="11.43" type="Double" />
<column name="VolChg,%" property="NumberFormat" value="0%" type="String" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="Address" value="$N$4" type="String" />
<column name="PriceVolumeMark" property="FormulaR1C1" value="=IF([@[VolChg,%]]&#60;1%,&#34;&#34;,IF([@[Chg,%]]&#60;-1%,-1,IF([@[Chg,%]]&#62;1%,1,&#34;&#34;)))" type="String" />
<column name="PriceVolumeMark" property="ColumnWidth" value="2.14" type="Double" />
<column name="PriceVolumeMark" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="PriceVolumeMark" property="Font.Size" value="10" type="Double" />
<column name="Close" property="FormatConditions(1).AppliesTo.Address" value="$G$4:$G$69" type="String" />
<column name="Close" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Close" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="853.67" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="1078.14" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="Chg,%" property="FormatConditions(1).AppliesTo.Address" value="$J$4:$J$69" type="String" />
<column name="Chg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Chg,%" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.0183920009744107" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="0.137962848366881" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="Volume" property="FormatConditions(1).AppliesTo.Address" value="$K$4:$K$69" type="String" />
<column name="Volume" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="912900" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="11566400" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).AppliesTo.Address" value="$M$4:$M$69" type="String" />
<column name="VolChg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.686306888919629" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="1.71938168846611" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).AppliesTo.Address" value="$N$4:$N$69" type="String" />
<column name="PriceVolumeMark" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconSet.ID" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Up in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=1" type="String" />
</view>
<view name="Up or Down in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="&#60;&#62;" type="String" />
</view>
<view name="Down in Volume">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=-1" type="String" />
</view>
<view name="Top 10 Up">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="3" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
</view>
<view name="Top 10 Down">
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="4" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'StockTradeHistory','<?xml version="1.0" encoding="Unicode"?>
<table name=".StockTradeHistory">
<columnFormats>
<column name="" property="ListObjectName" value="StockTradeHistory_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Symbol" property="Address" value="$C$4" type="String" />
<column name="Symbol" property="ColumnWidth" value="9.14" type="Double" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$D$4" type="String" />
<column name="Date" property="ColumnWidth" value="10.29" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="Address" value="$E$4" type="String" />
<column name="Open" property="ColumnWidth" value="7.86" type="Double" />
<column name="Open" property="NumberFormat" value="0.00" type="String" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="Address" value="$F$4" type="String" />
<column name="High" property="ColumnWidth" value="7.86" type="Double" />
<column name="High" property="NumberFormat" value="0.00" type="String" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="Address" value="$G$4" type="String" />
<column name="Low" property="ColumnWidth" value="7.86" type="Double" />
<column name="Low" property="NumberFormat" value="0.00" type="String" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="Address" value="$H$4" type="String" />
<column name="Close" property="ColumnWidth" value="7.86" type="Double" />
<column name="Close" property="NumberFormat" value="0.00" type="String" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="Address" value="$I$4" type="String" />
<column name="Chg" property="FormulaR1C1" value="=IF(R[1]C[-1]=0,0,[@Close]-R[1]C[-1])" type="String" />
<column name="Chg" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg" property="NumberFormat" value="0.00_ ;[Red]-0.00 " type="String" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="Address" value="$J$4" type="String" />
<column name="Chg,%" property="FormulaR1C1" value="=IF(([@Close]-[@Chg])=0,0,([@Chg]/([@Close]-[@Chg])))" type="String" />
<column name="Chg,%" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg,%" property="NumberFormat" value="0.00%" type="String" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="Address" value="$K$4" type="String" />
<column name="Volume" property="ColumnWidth" value="11.43" type="Double" />
<column name="Volume" property="NumberFormat" value="#,##0" type="String" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Volume Chg" property="Address" value="$L$4" type="String" />
<column name="Volume Chg" property="FormulaR1C1" value="=IF(R[1]C[-1]=0,0,[@Volume]-R[1]C[-1])" type="String" />
<column name="Volume Chg" property="NumberFormat" value="#,##0" type="String" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="VolChg,%" property="Address" value="$M$4" type="String" />
<column name="VolChg,%" property="FormulaR1C1" value="=IF(([@Volume]-[@[Volume Chg]])=0,0,[@[Volume Chg]]/([@Volume]-[@[Volume Chg]]))" type="String" />
<column name="VolChg,%" property="ColumnWidth" value="11.43" type="Double" />
<column name="VolChg,%" property="NumberFormat" value="0%" type="String" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="Address" value="$N$4" type="String" />
<column name="PriceVolumeMark" property="FormulaR1C1" value="=IF([@[VolChg,%]]&#60;1%,&#34;&#34;,IF([@[Chg,%]]&#60;-1%,-1,IF([@[Chg,%]]&#62;1%,1,&#34;&#34;)))" type="String" />
<column name="PriceVolumeMark" property="ColumnWidth" value="2.14" type="Double" />
<column name="PriceVolumeMark" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="PriceVolumeMark" property="Font.Size" value="10" type="Double" />
<column name="Close" property="FormatConditions(1).AppliesTo.Address" value="$H$4:$H$33" type="String" />
<column name="Close" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Close" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="32.11" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="38.87" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="Chg,%" property="FormatConditions(1).AppliesTo.Address" value="$J$4:$J$33" type="String" />
<column name="Chg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Chg,%" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.023418491484185" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="0.0429431072210066" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="Volume" property="FormatConditions(1).AppliesTo.Address" value="$K$4:$K$33" type="String" />
<column name="Volume" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="6455449" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="32439819" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).AppliesTo.Address" value="$M$4:$M$33" type="String" />
<column name="VolChg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.513025290970353" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="1.16912568033796" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).AppliesTo.Address" value="$N$4:$N$33" type="String" />
<column name="PriceVolumeMark" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconSet.ID" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="StockTradeHistory_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="Up in Volume">
<column name="" property="ListObjectName" value="StockTradeHistory_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=1" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="Up or Down in Volume">
<column name="" property="ListObjectName" value="StockTradeHistory_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="&#60;&#62;" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="Down in Volume">
<column name="" property="ListObjectName" value="StockTradeHistory_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=-1" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="Top 10 Up">
<column name="" property="ListObjectName" value="StockTradeHistory_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="3" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="Top 10 Down">
<column name="" property="ListObjectName" value="StockTradeHistory_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="4" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'QueryListDB','<?xml version="1.0" encoding="Unicode"?>
<table name="QueryListDB">
<columnFormats>
<column name="" property="ListObjectName" value="QueryListDB_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="64.71" type="Double" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="18.57" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_TYPE" property="Address" value="$F$7" type="String" />
<column name="TABLE_TYPE" property="ColumnWidth" value="13.14" type="Double" />
<column name="TABLE_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_TYPE" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_TYPE" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="INSERT_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="INSERT_PROCEDURE" property="Address" value="$G$7" type="String" />
<column name="INSERT_PROCEDURE" property="ColumnWidth" value="20.71" type="Double" />
<column name="INSERT_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="UPDATE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="UPDATE_PROCEDURE" property="Address" value="$H$7" type="String" />
<column name="UPDATE_PROCEDURE" property="ColumnWidth" value="21.71" type="Double" />
<column name="UPDATE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="DELETE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DELETE_PROCEDURE" property="Address" value="$I$7" type="String" />
<column name="DELETE_PROCEDURE" property="ColumnWidth" value="20.71" type="Double" />
<column name="DELETE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Stock Performance','<?xml version="1.0" encoding="Unicode"?>
<table name=".Stock Performance">
<columnFormats>
<column name="" property="ListObjectName" value="StockPerformance_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Type" property="Address" value="$C$4" type="String" />
<column name="Type" property="ColumnWidth" value="7.43" type="Double" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Symbol" property="Address" value="$D$4" type="String" />
<column name="Symbol" property="ColumnWidth" value="9.57" type="Double" />
<column name="StartDate" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="StartDate" property="Address" value="$E$4" type="String" />
<column name="StartDate" property="ColumnWidth" value="10.86" type="Double" />
<column name="StartDate" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="LastDate" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LastDate" property="Address" value="$F$4" type="String" />
<column name="LastDate" property="ColumnWidth" value="10.14" type="Double" />
<column name="LastDate" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="StartPrice" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="StartPrice" property="Address" value="$G$4" type="String" />
<column name="StartPrice" property="ColumnWidth" value="11.29" type="Double" />
<column name="StartPrice" property="NumberFormat" value="#,##0.00" type="String" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="Address" value="$H$4" type="String" />
<column name="High" property="ColumnWidth" value="7.43" type="Double" />
<column name="High" property="NumberFormat" value="#,##0.00" type="String" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="Address" value="$I$4" type="String" />
<column name="Low" property="ColumnWidth" value="7.71" type="Double" />
<column name="Low" property="NumberFormat" value="#,##0.00" type="String" />
<column name="LastPrice" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LastPrice" property="Address" value="$J$4" type="String" />
<column name="LastPrice" property="ColumnWidth" value="10.57" type="Double" />
<column name="LastPrice" property="NumberFormat" value="#,##0.00" type="String" />
<column name="Change" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Change" property="Address" value="$K$4" type="String" />
<column name="Change" property="ColumnWidth" value="9.14" type="Double" />
<column name="Change" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="Address" value="$L$4" type="String" />
<column name="Chg,%" property="ColumnWidth" value="11.29" type="Double" />
<column name="Chg,%" property="NumberFormat" value="0.0%" type="String" />
<column name="Chg,%" property="FormatConditions(1).AppliesTo.Address" value="$L$4:$L$5" type="String" />
<column name="Chg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Chg,%" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="0.0622" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="0.2015" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="Type" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Historical Prices','<?xml version="1.0" encoding="Unicode"?>
<table name=".Historical Prices">
<columnFormats>
<column name="" property="ListObjectName" value="HistoricalPrices_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Symbol" property="Address" value="$C$4" type="String" />
<column name="Symbol" property="ColumnWidth" value="9.14" type="Double" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$D$4" type="String" />
<column name="Date" property="ColumnWidth" value="10.29" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="Address" value="$E$4" type="String" />
<column name="Open" property="ColumnWidth" value="7.86" type="Double" />
<column name="Open" property="NumberFormat" value="0.00" type="String" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="Address" value="$F$4" type="String" />
<column name="High" property="ColumnWidth" value="7.86" type="Double" />
<column name="High" property="NumberFormat" value="0.00" type="String" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="Address" value="$G$4" type="String" />
<column name="Low" property="ColumnWidth" value="7.86" type="Double" />
<column name="Low" property="NumberFormat" value="0.00" type="String" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="Address" value="$H$4" type="String" />
<column name="Close" property="ColumnWidth" value="7.86" type="Double" />
<column name="Close" property="NumberFormat" value="0.00" type="String" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="Address" value="$I$4" type="String" />
<column name="Chg" property="FormulaR1C1" value="=IF(R[1]C[-1]=0,0,[@Close]-R[1]C[-1])" type="String" />
<column name="Chg" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg" property="NumberFormat" value="0.00_ ;[Red]-0.00 " type="String" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="Address" value="$J$4" type="String" />
<column name="Chg,%" property="FormulaR1C1" value="=IF(([@Close]-[@Chg])=0,0,([@Chg]/([@Close]-[@Chg])))" type="String" />
<column name="Chg,%" property="ColumnWidth" value="7.86" type="Double" />
<column name="Chg,%" property="NumberFormat" value="0.00%" type="String" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="Address" value="$K$4" type="String" />
<column name="Volume" property="ColumnWidth" value="11.43" type="Double" />
<column name="Volume" property="NumberFormat" value="#,##0" type="String" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Volume Chg" property="Address" value="$L$4" type="String" />
<column name="Volume Chg" property="FormulaR1C1" value="=IF(R[1]C[-1]=0,0,[@Volume]-R[1]C[-1])" type="String" />
<column name="Volume Chg" property="NumberFormat" value="#,##0" type="String" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="VolChg,%" property="Address" value="$M$4" type="String" />
<column name="VolChg,%" property="FormulaR1C1" value="=IF(([@Volume]-[@[Volume Chg]])=0,0,[@[Volume Chg]]/([@Volume]-[@[Volume Chg]]))" type="String" />
<column name="VolChg,%" property="ColumnWidth" value="11.43" type="Double" />
<column name="VolChg,%" property="NumberFormat" value="0%" type="String" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="Address" value="$N$4" type="String" />
<column name="PriceVolumeMark" property="FormulaR1C1" value="=IF([@[VolChg,%]]&#60;1%,&#34;&#34;,IF([@[Chg,%]]&#60;-1%,-1,IF([@[Chg,%]]&#62;1%,1,&#34;&#34;)))" type="String" />
<column name="PriceVolumeMark" property="ColumnWidth" value="2.14" type="Double" />
<column name="PriceVolumeMark" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="PriceVolumeMark" property="Font.Size" value="10" type="Double" />
<column name="Close" property="FormatConditions(1).AppliesTo.Address" value="$H$4:$H$33" type="String" />
<column name="Close" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Close" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="1007.95" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="1078.14" type="Double" />
<column name="Close" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="Chg,%" property="FormatConditions(1).AppliesTo.Address" value="$J$4:$J$33" type="String" />
<column name="Chg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Chg,%" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.0250564526034334" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="0.0323936792820913" type="Double" />
<column name="Chg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="Volume" property="FormatConditions(1).AppliesTo.Address" value="$K$4:$K$33" type="String" />
<column name="Volume" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="914624" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="16776444" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="2" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="2287182" type="Double" />
<column name="Volume" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8109667" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).AppliesTo.Address" value="$M$4:$M$33" type="String" />
<column name="VolChg,%" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="-0.451591521794068" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="1.021159065021" type="Double" />
<column name="VolChg,%" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).AppliesTo.Address" value="$N$4:$N$33" type="String" />
<column name="PriceVolumeMark" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconSet.ID" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" />
<column name="PriceVolumeMark" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="HistoricalPrices_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="Up in Volume">
<column name="" property="ListObjectName" value="HistoricalPrices_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=1" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="Up or Down in Volume">
<column name="" property="ListObjectName" value="HistoricalPrices_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="&#60;&#62;" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="Down in Volume">
<column name="" property="ListObjectName" value="HistoricalPrices_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="AutoFilter.Criteria1" value="=-1" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="Top 10 Up">
<column name="" property="ListObjectName" value="HistoricalPrices_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="3" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="Top 10 Down">
<column name="" property="ListObjectName" value="HistoricalPrices_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Symbol" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Open" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="High" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Low" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Close" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Volume Chg" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="VolChg,%" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PriceVolumeMark" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Chg,%" property="AutoFilter.Operator" value="4" type="Double" />
<column name="Chg,%" property="AutoFilter.Criteria1" value="10" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="Symbol" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="2" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
</views>
</table>
');
GO

-- print Web Finance Database has been installed
